# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1Claim(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'export': 'V1ExportClaim',
        'export_to': 'V1ExportableReference',
        '_import': 'V1ImportClaim',
        'import_source': 'V1ImportableReference',
        'mount': 'V1MountClaim',
        'volume_capacity': 'str'
    }

    attribute_map = {
        'export': 'export',
        'export_to': 'export_to',
        '_import': 'import',
        'import_source': 'import_source',
        'mount': 'mount',
        'volume_capacity': 'volume_capacity'
    }

    def __init__(self, export=None, export_to=None, _import=None, import_source=None, mount=None, volume_capacity=None, local_vars_configuration=None):  # noqa: E501
        """V1Claim - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._export = None
        self._export_to = None
        self.__import = None
        self._import_source = None
        self._mount = None
        self._volume_capacity = None
        self.discriminator = None

        if export is not None:
            self.export = export
        if export_to is not None:
            self.export_to = export_to
        if _import is not None:
            self._import = _import
        if import_source is not None:
            self.import_source = import_source
        if mount is not None:
            self.mount = mount
        self.volume_capacity = volume_capacity

    @property
    def export(self):
        """Gets the export of this V1Claim.  # noqa: E501


        :return: The export of this V1Claim.  # noqa: E501
        :rtype: V1ExportClaim
        """
        return self._export

    @export.setter
    def export(self, export):
        """Sets the export of this V1Claim.


        :param export: The export of this V1Claim.  # noqa: E501
        :type export: V1ExportClaim
        """

        self._export = export

    @property
    def export_to(self):
        """Gets the export_to of this V1Claim.  # noqa: E501


        :return: The export_to of this V1Claim.  # noqa: E501
        :rtype: V1ExportableReference
        """
        return self._export_to

    @export_to.setter
    def export_to(self, export_to):
        """Sets the export_to of this V1Claim.


        :param export_to: The export_to of this V1Claim.  # noqa: E501
        :type export_to: V1ExportableReference
        """

        self._export_to = export_to

    @property
    def _import(self):
        """Gets the _import of this V1Claim.  # noqa: E501


        :return: The _import of this V1Claim.  # noqa: E501
        :rtype: V1ImportClaim
        """
        return self.__import

    @_import.setter
    def _import(self, _import):
        """Sets the _import of this V1Claim.


        :param _import: The _import of this V1Claim.  # noqa: E501
        :type _import: V1ImportClaim
        """

        self.__import = _import

    @property
    def import_source(self):
        """Gets the import_source of this V1Claim.  # noqa: E501


        :return: The import_source of this V1Claim.  # noqa: E501
        :rtype: V1ImportableReference
        """
        return self._import_source

    @import_source.setter
    def import_source(self, import_source):
        """Sets the import_source of this V1Claim.


        :param import_source: The import_source of this V1Claim.  # noqa: E501
        :type import_source: V1ImportableReference
        """

        self._import_source = import_source

    @property
    def mount(self):
        """Gets the mount of this V1Claim.  # noqa: E501


        :return: The mount of this V1Claim.  # noqa: E501
        :rtype: V1MountClaim
        """
        return self._mount

    @mount.setter
    def mount(self, mount):
        """Sets the mount of this V1Claim.


        :param mount: The mount of this V1Claim.  # noqa: E501
        :type mount: V1MountClaim
        """

        self._mount = mount

    @property
    def volume_capacity(self):
        """Gets the volume_capacity of this V1Claim.  # noqa: E501


        :return: The volume_capacity of this V1Claim.  # noqa: E501
        :rtype: str
        """
        return self._volume_capacity

    @volume_capacity.setter
    def volume_capacity(self, volume_capacity):
        """Sets the volume_capacity of this V1Claim.


        :param volume_capacity: The volume_capacity of this V1Claim.  # noqa: E501
        :type volume_capacity: str
        """

        self._volume_capacity = volume_capacity

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Claim):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Claim):
            return True

        return self.to_dict() != other.to_dict()
